pub enum FleissMethod {
Fleiss,
Randolph,
}Expand description
Chance-correction convention used by fleiss_kappa.
Variants
Fleiss
Fleiss’ kappa: the chance outcome uses the sample marginal of categories.
Randolph
Randolph’s (uniform) kappa: the chance outcome assumes a uniform distribution over categories.