TukeyHsdResult

Struct TukeyHsdResult 

pub struct TukeyHsdResult {
    pub pairs: Vec<(usize, usize)>,
    pub meandiffs: Vec<f64>,
    pub std_pairs: Vec<f64>,
    pub confint: Vec<(f64, f64)>,
    pub pvalues: Vec<f64>,
    pub reject: Vec<bool>,
    pub q_crit: f64,
    pub df_total: f64,
    pub variance: f64,
}
Result of a pairwise Tukey HSD comparison.

Fields

pairs: Vec<(usize, usize)>

(i, j) group-index pairs (upper triangle, i < j).

meandiffs: Vec<f64>

Mean difference mean_j − mean_i for each pair.

std_pairs: Vec<f64>

Standard error of each pairwise difference (studentized-range scaling).

confint: Vec<(f64, f64)>

Lower and upper confidence bounds for each mean difference.

pvalues: Vec<f64>

Studentized-range adjusted p-value for each pair.

reject: Vec<bool>

Reject the null of equal means at level alpha.

q_crit: f64

Critical value of the studentized range at level alpha.

df_total: f64

Total residual degrees of freedom N − k.

variance: f64

Pooled within-group variance (mean squared error).